==> galileo-0.2.0-py3-none-any.whl: galileo/resources/models/generated_scorer_validation_response.py <==
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="GeneratedScorerValidationResponse")


@_attrs_define
class GeneratedScorerValidationResponse:
    """
    Attributes:
        task_result_id (str):
    """

    task_result_id: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        task_result_id = self.task_result_id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"task_result_id": task_result_id})

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: dict[str, Any]) -> T:
        d = src_dict.copy()
        task_result_id = d.pop("task_result_id")

        generated_scorer_validation_response = cls(task_result_id=task_result_id)

        generated_scorer_validation_response.additional_properties = d
        return generated_scorer_validation_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> galileo-1.22.0-py3-none-any.whl: galileo/resources/models/generated_scorer_validation_response.py <==
from collections.abc import Mapping
from typing import Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="GeneratedScorerValidationResponse")


@_attrs_define
class GeneratedScorerValidationResponse:
    """
    Attributes:
        task_result_id (str):
    """

    task_result_id: str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        task_result_id = self.task_result_id

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({"task_result_id": task_result_id})

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        task_result_id = d.pop("task_result_id")

        generated_scorer_validation_response = cls(task_result_id=task_result_id)

        generated_scorer_validation_response.additional_properties = d
        return generated_scorer_validation_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
